@@ -1,24 +1,19 @@
+import logging
+from config import etl_logger
+
 from data_job_etl.extract.extract import Extractor
 from data_job_etl.transform.preprocess import Preprocessor
 from data_job_etl.transform.process import Processor
 from data_job_etl.load.load import Loader
-from data_job_etl.load.create_tables import create_tables
 
 
-def etl():
-    """
-    ETL pipeline.
-    """
-    # Create tables
-    create_tables()
-
-    # Extraction
-    print('Extracting')
+def extract():
     extractor = Extractor()
     raw_jobs = extractor.extract_raw_jobs()
+    return raw_jobs
 
-    # Transformation
-    print('Transforming')
+
+def transform(raw_jobs):
     preprocessor = Preprocessor(raw_jobs)
     preprocessor.preprocess()
     preprocessed_jobs = preprocessor.jobs
@@ -26,12 +21,23 @@ def etl():
     processor = Processor()
     processed_jobs = processor.process_technos(preprocessed_jobs)
     pivotted_jobs = processor.pivot_technos(processed_jobs)
+    return processed_jobs, pivotted_jobs
 
-    print(pivotted_jobs.head())
 
-    # Loading
-    print('Loading')
+def load(processed_jobs, pivotted_jobs):
     loader = Loader()
     loader.load_processed(processed_jobs)
     loader.load_pivotted(pivotted_jobs)
 
+
+def main():
+    try:
+        raw_jobs = extract()
+        processed_jobs, pivotted_jobs = transform(raw_jobs)
+        load(processed_jobs, pivotted_jobs)
+    except Exception as e:
+        logging.exception("Exception occurred")
+
+
+if __name__ == "__main__":
+    main()
