@@ -18,7 +18,7 @@ class Preprocessor:
     @staticmethod
     def cast_types(jobs):
         jobs = jobs.convert_dtypes()
-        jobs['id'] = jobs['id'].values.astype(np.int16)
+        jobs['id'] = jobs['id'].values.astype(int)
         jobs['created_at'] = pd.to_datetime(jobs['created_at'])
         return jobs
 
@@ -29,7 +29,16 @@ class Preprocessor:
 
     @staticmethod
     def process_title(title):
-        gender_regex = '[(]?[HhFfMmWwXxTt]{1}[\s]?[\/]?[\s]?[HFMWDXmfdwST]{1}[)]?[\/]?[HFMWDXmfdwST]?[)]?'
+        HF = r'\(?H\s?\/?\s?F\)?'
+        FHX = r'\(?F\s?\/?\s?H\)?\/?X?\)?'
+        MFD = r'\(?M\s?\/?\s?F\)?\/?D?\)?'
+        FMD = r'\(?F\s?\/?\s?M\)?\/?D?\)?'
+        mfd = r'\(m\/f\/d\)'
+        fmd = r'\(f\/m\/d\)'
+        mwd = r'\(m\/w\/d\)'
+        HST = r'\(H\/S\/T\)'
+        MW = r'M\/W'
+        gender_regex = f'{HF}|{MFD}|{FMD}|{FHX}|{mfd}|{fmd}|{mwd}|{HST}|{MW}'
         title = re.sub(gender_regex, '', title)
         title = title.strip()
         return title
